---
name: Bug
about: Create a report to help us improve

---

# Bug report

<!--
Hi, thanks for submitting a bug. We appreciate that.

But, we will need some information about what's wrong to help you.
-->

## What's wrong

<!-- Describe what is not working. Please, attach a traceback. -->

## How is that should be

<!-- Describe how it should work. -->

## System information

<!-- Describe system information -->
